##
##  binaryen.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 119
%define       V_snap 20240906

#   package information
Name:         binaryen
Summary:      WebAssembly Toolkit
URL:          https://github.com/WebAssembly/binaryen
Vendor:       WebAssembly
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Language
License:      Apache
Version:      %{V_base}
Release:      20240906

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/binaryen/binaryen-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, cmake
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Binaryen is a compiler and toolchain infrastructure library
    for WebAssembly, written in C++. It aims to make compiling to
    WebAssembly easy, fast, and effective: Binaryen has a simple C API
    in a single header, and can also be used from JavaScript. It accepts
    input in WebAssembly-like form but also accepts a general control
    flow graph for compilers that prefer that. Binaryen's internal IR
    uses compact data structures and is designed for completely parallel
    codegen and optimization, using all available CPU cores. Binaryen's
    IR also compiles down to WebAssembly extremely easily and quickly
    because it is essentially a subset of WebAssembly.

%track
    prog binaryen = {
        version   = %{V_base}
        url       = https://github.com/WebAssembly/binaryen/releases
        regex     = tree/version_(\d+)
    }

%prep
    %setup -q -n binaryen

%build
    mkdir build
    cd build
    cmake \
        -Wno-dev \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DCMAKE_CXX_FLAGS="%{l_cxxflags} %{l_cppflags}" \
        -DBUILD_STATIC_LIB=ON \
        ..
    %{l_make} %{l_mflags -O}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/include/binaryen
    strip build/bin/* >/dev/null 2>%1 || true
    %{l_shtool} install -c -m 755 \
        build/bin/* $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 755 \
        build/lib/*.a $RPM_BUILD_ROOT%{l_prefix}/lib/
    (   cd src
        find . -name "*.h" -print | xargs %{l_tar} cf - | \
        (   cd $RPM_BUILD_ROOT%{l_prefix}/include/binaryen
            %{l_tar} xf -
        ) || exit %?
    ) || exit %?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

